Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Challenges []Challenge
Challenges contains all of the Kubernetes challenges
Functions ¶
This section is empty.
Types ¶
type Challenge ¶
type Challenge struct {
Name string
Description string
AllowedTime time.Duration
ClusterName string
DeployFunc func(ctx context.Context, clientSet *kubernetes.Clientset, r *rest.Config) error
Readme string
}
Challenge is an individual challenge, with a specified time limit
func SelectChallenge ¶
func (*Challenge) CreateReadme ¶
CreateReadme will write a readme to the home directory, it can contain clues and other useful information
Click to show internal directories.
Click to hide internal directories.